@@ -65,21 +65,12 @@ def get_shell():
             'csh',
         ]
 
-        if compat.platform == 'win':
-            py_proc = 'py*.exe'
-        else:
-            py_proc = 'python*'
-
-        proc = psutil.Process()
-        while True:
+        process_parents = psutil.Process().parents()
+        for proc in process_parents[::-1]:
             exe = proc.exe()
             exe_name = os.path.basename(exe)
-            if fnmatch.fnmatch(exe_name, py_proc):
-                proc = proc.parent()
-                continue
             if exe_name in supported_shells:
                 return exe
-            break
     except ImportError:
         pass
 
@@ -118,21 +109,27 @@ def get_subshell_command(prefix):
     '''Return a command to launch a subshell'''
 
     shell = get_shell()
+    try:
+        disable_prompt = int(os.getenv('CPENV_DISABLE_PROMPT', 0))
+    except:
+        disable_prompt = 0
+
     prompt = get_prompt(shell, prefix)
 
     if shell.endswith('cmd.exe'):
-        os.environ['PROMPT'] = prompt
+        if not disable_prompt:
+            os.environ['PROMPT'] = prompt
         return [shell, '/K']
 
     if shell.endswith('powershell.exe'):
-        return [
-            shell,
-            '-NoExit',
-            '-Command',
-            "function Prompt {%s}" % prompt
-        ]
+        args = [shell, '-NoExit', '-NoLogo']
+        if not disable_prompt:
+            args += ['-Command', "function Prompt {%s}" % prompt]
+        return args
 
     if shell.endswith('bash'):
+        if not disable_prompt:
+            os.environ['PROMPT'] = prompt
         return [shell, binpath('subshell.sh')]
 
     return [shell]
